###################################################
### chunk number 1: preliminaries
###################################################
#line 31 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
options(width=80, show.signif.stars = FALSE,
        lattice.theme = function() canonical.theme("pdf", color = FALSE))
library(mlmRev)
library(lme4)
set.seed(1234321)


###################################################
### chunk number 2: Examprep
###################################################
#line 109 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
lmer(normexam ~ standLRT + sex + schgend + (1|school), Exam)


###################################################
### chunk number 3: ExamData
###################################################
#line 123 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
str(Exam)
summary(Exam)


###################################################
### chunk number 4: ExamFit
###################################################
#line 137 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
(Em1 <- lmer(normexam ~ standLRT + sex + schgend + (1|school), Exam))


###################################################
### chunk number 5: Examtime
###################################################
#line 152 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
system.time(lmer(normexam ~ standLRT + sex + schgend + (1|school), Exam))


###################################################
### chunk number 6: ExamRelevel
###################################################
#line 185 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
Exam$sex     <- relevel(Exam$sex, "M")
Exam$schgend <- relevel(Exam$schgend, "girls")
(Em2 <- lmer(normexam ~ standLRT + sex + schgend + (1|school), Exam))


###################################################
### chunk number 7: ExamIds
###################################################
#line 216 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
Exam <- within(Exam, ids <- factor(school:student))
str(Exam)


###################################################
### chunk number 8: dupExamIds
###################################################
#line 224 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
as.character(Exam$ids[which(duplicated(Exam$ids))])


###################################################
### chunk number 9: OnlyBoy
###################################################
#line 229 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
subset(Exam, ids == '43:86')
xtabs(~ sex + school, Exam, subset = school %in% c(43, 50, 52), drop = TRUE)


###################################################
### chunk number 10: ExamXtabs
###################################################
#line 245 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
xtabs(~ sex + school, Exam, subset = type == "Mxd", drop = TRUE)


###################################################
### chunk number 11: ExamMosaicshow eval=FALSE
###################################################
## #line 259 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
## ExamMxd <- within(subset(Exam, type == "Mxd"), school <- factor(school))
## mosaicplot(~ school + sex, ExamMxd)


###################################################
### chunk number 12: ExamMosaic
###################################################
#line 267 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
ExamMxd <- within(subset(Exam, type == "Mxd"), school <- factor(school))
mosaicplot(~ school + sex, ExamMxd)


###################################################
### chunk number 13: Examplot1
###################################################
#line 292 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(xyplot(normexam ~ standLRT | sex * type, Exam,
             type = c("g", "p", "smooth"), layout = c(2,2),
             xlab = "Standardized London Reading Test score",
             ylab = "Normalized exam score", aspect = 1.2))


###################################################
### chunk number 14: Examplot1show eval=FALSE
###################################################
## #line 311 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
## xyplot(normexam ~ standLRT | sex * type, Exam, type = c("g", "p", "smooth"))


###################################################
### chunk number 15: Examplot2
###################################################
#line 330 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(xyplot(normexam ~ standLRT, Exam, groups = sex:type,
             type = c("g", "smooth"), xlim = c(-3,3), ylim = c(-2,2),
             xlab = "Standardized London Reading Test score",
             ylab = "Normalized exam score",
             auto.key = list(space = 'right', points = FALSE, lines = TRUE),
             aspect = 1))


###################################################
### chunk number 16: Examplot2show eval=FALSE
###################################################
## #line 345 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
## xyplot(normexam ~ standLRT, Exam, groups = sex:type, type = c("g", "smooth"))


###################################################
### chunk number 17: Examplot3
###################################################
#line 390 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(xyplot(normexam ~ standLRT | school, Exam,
             type = c("g", "p", "r"),
             xlab = "Standardized London Reading Test score",
             ylab = "Normalized exam score",
             subset = sex == "F" & type == "Sngl"))


###################################################
### chunk number 18: Examplot3show
###################################################
#line 406 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
xyplot(normexam ~ standLRT | school, Exam,
             type = c("g", "p", "r"),
             subset = sex == "F" & type == "Sngl")


###################################################
### chunk number 19: Examplot4show eval=FALSE
###################################################
## #line 423 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
## xyplot(normexam ~ standLRT | school, Exam, type = c("g", "p", "r"),
##              subset = sex == "F" & type == "Sngl" & school != 48,
##              index.cond = function(x, y) coef(lm(y ~ x))[1])


###################################################
### chunk number 20: Examplot4
###################################################
#line 430 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(xyplot(normexam ~ standLRT | school, Exam,
             type = c("g", "p", "r"),
             xlab = "Standardized London Reading Test score",
             ylab = "Normalized exam score",
             subset = sex == "F" & type == "Sngl" & school != 48,
             index.cond = function(x, y) coef(lm(y ~ x))[1]))


###################################################
### chunk number 21: Examplot4a
###################################################
#line 454 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(xyplot(normexam ~ standLRT | school, Exam,
             type = c("g", "p", "r"),
             xlab = "Standardized London Reading Test score",
             ylab = "Normalized exam score",
             subset = sex == "F" & type == "Sngl" & school != 48,
             index.cond = function(x, y) coef(lm(y ~ x))[2]))


###################################################
### chunk number 22: ExamLmListFS
###################################################
#line 475 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
show(ExamFS <- lmList(normexam ~ standLRT | school, Exam,
                      subset = sex == "F" & type == "Sngl" & school != 48))


###################################################
### chunk number 23: Examplot4cshow
###################################################
#line 480 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
plot(confint(ExamFS, pool = TRUE), order = 1)


###################################################
### chunk number 24: Examplot4c
###################################################
#line 485 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(plot(confint(ExamFS, pool = TRUE), order = 1))


###################################################
### chunk number 25: Examplot5
###################################################
#line 498 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(xyplot(normexam ~ standLRT | school, Exam,
             type = c("g", "p", "r"),
             xlab = "Standardized London Reading Test score",
             ylab = "Normalized exam score",
             subset = sex == "M" & type == "Sngl", layout = c(5,2),
             index.cond = function(x, y) coef(lm(y ~ x))[1]))


###################################################
### chunk number 26: ExamLmListMS
###################################################
#line 512 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
show(ExamMS <- lmList(normexam ~ standLRT | school, Exam,
                      subset = sex == "M" & type == "Sngl"))


###################################################
### chunk number 27: Examplot5b
###################################################
#line 520 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(plot(confint(ExamMS, pool = TRUE), order = 1))


###################################################
### chunk number 28: Examplot6
###################################################
#line 534 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(xyplot(normexam ~ standLRT | school, Exam, groups = sex,
             type = c("g", "p", "r"),
             xlab = "Standardized London Reading Test score",
             ylab = "Normalized exam score",
             subset = !school %in% c(43, 47) & type == "Mxd",
             index.cond = function(x, y) coef(lm(y ~ x))[1],
             auto.key = list(space = 'top', lines = TRUE,
             columns = 2), layout = c(7,5),
             aspect = 1.2))


###################################################
### chunk number 29: ExamLmListM
###################################################
#line 551 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
show(ExamM <- lmList(normexam ~ standLRT + sex| school, Exam,
                     subset = type == "Mxd" & !school %in% c(43,47,54)))


###################################################
### chunk number 30: Examplot6b
###################################################
#line 558 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
print(plot(confint(ExamM, pool = TRUE), order = 1))


###################################################
### chunk number 31: Em3
###################################################
#line 579 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
(Em3 <- lmer(normexam ~ standLRT + sex + type + (1|school), Exam))


###################################################
### chunk number 32: Em4
###################################################
#line 585 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
(Em4 <- lmer(normexam ~ standLRT + sex + type + (standLRT|school), Exam))


###################################################
### chunk number 33: EmAnova
###################################################
#line 589 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
anova(Em3, Em4)


###################################################
### chunk number 34: Em5
###################################################
#line 610 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
(Em5 <- lmer(normexam ~ standLRT + sex + type + (standLRT + sex|school), Exam))


###################################################
### chunk number 35: Oxboys
###################################################
#line 620 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
str(Oxboys)
system.time(mX1 <- lmer(height ~ age + I(age^2) + I(age^3) + I(age^4) + (age + I(age^2)|Subject),
                       Oxboys))
summary(mX1)
system.time(mX2 <- lmer(height ~ poly(age,4) + (age + I(age^2)|Subject), Oxboys))
summary(mX2)


###################################################
### chunk number 36: ScotsSec
###################################################
#line 632 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
str(ScotsSec)
system.time(mS1 <- lmer(attain ~ sex + (1|primary) + (1|second), ScotsSec))
summary(mS1)


###################################################
### chunk number 37: sessionInfo
###################################################
#line 640 "d:/Rcompile/CRANpkg/local/2.12/mlmRev/inst/doc/MlmSoftRev.Rnw"
toLatex(sessionInfo())


